
"""
Plot up files from the Hinwood project.
"""
from os import sep
import project
from time import localtime, strftime

def plot_compare_csv(location_sim, file_sim, location_exp, file_exp,
                     y_label,
                     save_as=None,
                     plot_title="",
                     x_label='Time (s)',
                     legend_sim='ANUGA simulation',
                     legend_exp='Measured flume result',
                     is_interactive=False):
    """ 
    """
    from pylab import ion, plot, xlabel, ylabel, close, legend, \
         savefig, title
    from anuga.shallow_water.data_manager import csv2dict



    # Load in the csv files and convert info from strings to floats
    simulation, _ = csv2dict(file_sim)
    experiment, _ = csv2dict(file_exp)
    time_sim = [float(x) for x in simulation['time']]
    quantity_sim = [float(x) for x in simulation[location_sim]]
    #print "quantity_sim", quantity_sim
    time_exp = [float(x) for x in experiment['Time']]
    quantity_exp = [float(x) for x in experiment[location_exp]]

    if is_interactive:
        ion()
    
    plot(time_sim, quantity_sim, time_exp, quantity_exp)

    # Add axis stuff and legend
    xlabel(x_label)
    ylabel(y_label)
    # The order defines the label
    #legend((legend_exp, legend_sim),'upper left')
    legend((legend_sim, legend_exp),'upper left')
    title(plot_title)
    
    if is_interactive:
        # Wait for enter pressed
        raw_input()

    if save_as is not None:
        savefig(save_as)
    
    #Need to close this plot
    close()
    
def Hinwood_files_locations(run_data, outputdir_tag, plot_type):
    
    id = run_data['scenario_id']
    outputdir_name = id + outputdir_tag
    pro_instance = project.Project(['data','flumes','Hinwood_2008'],
                                   outputdir_name=outputdir_name)
    
    file_sim = pro_instance.outputdir + "depth_" + id + ".csv"
    #print "file_exp",file_exp
    file_exp = pro_instance.raw_data_dir + sep + id + 'pressfilt_exp_depth.csv'
    #print "file_sim", file_sim
    location_sims = []
    location_exps = []
    save_as_list = []
    for gauge_x in run_data['gauge_x']:
        gauge_x = str(gauge_x)
        location_sims.append(gauge_x + ':0.5')
        location_exps.append(gauge_x)
        save_as_list.append(pro_instance.plots_dir + sep + \
                            outputdir_name + "_" + gauge_x + plot_type)
    return file_exp, file_sim, location_sims, location_exps, outputdir_name, \
           save_as_list
def plot():
    from scenarios import scenarios
    outputdir_tag = "_good_tri_area_0.01_A"
    outputdir_tag = "_test"
    #scenarios = scenarios[1] # !!!!!!!!!!!!!!!!!!!!!! 
    #scenarios = [scenarios[5]] # !!!!!!!!!!!!!!!!!!!!!! 
    # Supported formats: emf, eps, pdf, png, ps, raw, rgba, svg, svgz.
    plot_type = ".pdf"
    for run_data in scenarios:
        
        temp = Hinwood_files_locations(run_data, outputdir_tag, plot_type)
        file_exp, file_sim, location_sims, location_exps, outputdir_name, \
                  save_as_list = temp
        print "run_data['scenario_id']", run_data['scenario_id']
        #location_sims = [location_sims[0]]
        #location_exps = [location_exps[0]]
        #save_as_list = [save_as_list[0]]
        for loc_sim, loc_exp, save_as, gauge in map(None, location_sims,
                                                    location_exps,
                                                    save_as_list,
                                                    run_data['gauge_x']):
            time_date = strftime('plot date: %d/%m/%Y Time: %H:%M:%S',
                                      localtime())
            plot_title = "Scenario: " + outputdir_name + "\n" + \
                         "X Gauge (m):" + str(gauge) + "    " + time_date
                         
            print "Doing ", plot_title
            plot_compare_csv(location_sim=loc_sim,
                             file_sim=file_sim,
                             location_exp=loc_exp,
                             file_exp=file_exp,
                             plot_title=plot_title,
                             y_label='Water height (m)',
                             is_interactive=False,
                             save_as=save_as)
    
#-------------------------------------------------------------
if __name__ == "__main__":
    """ Plot the stage graph for the ANUGA validation papar
    """
    from scenarios import scenarios
    outputdir_tag = "_good_tri_area_0.01_A"
    #scenarios = scenarios[1] # !!!!!!!!!!!!!!!!!!!!!! 
    scenarios = [scenarios[5]] # !!!!!!!!!!!!!!!!!!!!!! 
    # Supported formats: emf, eps, pdf, png, ps, raw, rgba, svg, svgz.
    plot_type = ".pdf"
    for run_data in scenarios:
        
        temp = Hinwood_files_locations(run_data, outputdir_tag, plot_type)
        file_exp, file_sim, location_sims, location_exps, outputdir_name, \
                  save_as_list = temp
        print "run_data['scenario_id']", run_data['scenario_id']
        #location_sims = [location_sims[0]]
        #location_exps = [location_exps[0]]
        #save_as_list = [save_as_list[0]]
        for loc_sim, loc_exp, save_as, gauge in map(None, location_sims,
                                                    location_exps,
                                                    save_as_list,
                                                    run_data['gauge_x']):
            time_date = strftime('plot date: %d/%m/%Y Time: %H:%M:%S',
                                      localtime())
            plot_title = "Scenario: " + outputdir_name + "\n" + \
                         "X Gauge (m):" + str(gauge) + "    " + time_date
                         
            print "Doing ", plot_title
            plot_compare_csv(location_sim=loc_sim,
                             file_sim=file_sim,
                             location_exp=loc_exp,
                             file_exp=file_exp,
                             plot_title=plot_title,
                             y_label='Water height (m)',
                             is_interactive=False,
                             save_as=save_as)

